aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2004-01-31 04:10:05 +0000
committerGuy Harris <guy@alum.mit.edu>2004-01-31 04:10:05 +0000
commitf914e6e9e7f3957fbd3a93ee107cc4c06901ca5b (patch)
treebb5fe5dd89c5d537fa6c919525754cfd5e948a73 /epan
parenta4464a67882161774cc0d00b75a0072ba2a61a27 (diff)
Fix the spelling of "cumulative" (and variables whose names derive from
that spelling). svn path=/trunk/; revision=9917
Diffstat (limited to 'epan')
-rw-r--r--epan/column-utils.c7
-rw-r--r--epan/column_info.h4
-rw-r--r--epan/frame_data.h4
3 files changed, 8 insertions, 7 deletions
diff --git a/epan/column-utils.c b/epan/column-utils.c
index c94281f89d..3e8901a608 100644
--- a/epan/column-utils.c
+++ b/epan/column-utils.c
@@ -1,7 +1,7 @@
/* column-utils.c
* Routines for column utilities.
*
- * $Id: column-utils.c,v 1.43 2004/01/29 03:37:31 guy Exp $
+ * $Id: column-utils.c,v 1.44 2004/01/31 04:10:04 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -875,8 +875,9 @@ fill_in_columns(packet_info *pinfo)
strcpy(pinfo->cinfo->col_expr[i], "frame.pkt_len");
strcpy(pinfo->cinfo->col_expr_val[i], pinfo->cinfo->col_buf[i]);
break;
- case COL_CULMULATIVE_BYTES:
- snprintf(pinfo->cinfo->col_buf[i], COL_MAX_LEN, "%u", pinfo->fd->cul_bytes);
+
+ case COL_CUMULATIVE_BYTES:
+ snprintf(pinfo->cinfo->col_buf[i], COL_MAX_LEN, "%u", pinfo->fd->cum_bytes);
pinfo->cinfo->col_data[i] = pinfo->cinfo->col_buf[i];
break;
diff --git a/epan/frame_data.h b/epan/frame_data.h
index 21faaaab1e..d45a820c3b 100644
--- a/epan/frame_data.h
+++ b/epan/frame_data.h
@@ -1,7 +1,7 @@
/* frame_data.h
* Definitions for frame_data structures and routines
*
- * $Id: frame_data.h,v 1.12 2004/01/10 13:15:41 jmayer Exp $
+ * $Id: frame_data.h,v 1.13 2004/01/31 04:10:05 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -50,7 +50,7 @@ typedef struct _frame_data {
guint32 num; /* Frame number */
guint32 pkt_len; /* Packet length */
guint32 cap_len; /* Amount actually captured */
- guint32 cul_bytes; /* Culmulative bytes into the capture */
+ guint32 cum_bytes; /* Cumulative bytes into the capture */
gint32 rel_secs; /* Relative seconds (yes, it can be negative) */
gint32 rel_usecs; /* Relative microseconds (yes, it can be negative) */
guint32 abs_secs; /* Absolute seconds */
diff --git a/epan/column_info.h b/epan/column_info.h
index 790211c556..51b6661b6a 100644
--- a/epan/column_info.h
+++ b/epan/column_info.h
@@ -1,7 +1,7 @@
/* column.h
* Definitions for column structures and routines
*
- * $Id: column_info.h,v 1.11 2003/12/09 06:48:39 guy Exp $
+ * $Id: column_info.h,v 1.12 2004/01/31 04:10:04 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -85,7 +85,7 @@ enum {
COL_PROTOCOL, /* Protocol */
COL_INFO, /* Description */
COL_PACKET_LENGTH, /* Packet length in bytes */
- COL_CULMULATIVE_BYTES, /* Culmulative number of bytes */
+ COL_CUMULATIVE_BYTES, /* Cumulative number of bytes */
COL_OXID, /* Fibre Channel OXID */
COL_RXID, /* Fibre Channel RXID */
COL_IF_DIR, /* FW-1 monitor interface/direction */